@@ -521,10 +521,17 @@ static void _xfdashboard_stage_on_view_activated(XfdashboardStage *self, Xfdashb
 		priv->viewBeforeSearch=XFDASHBOARD_VIEW(g_object_ref(inView));
 	}
 
-	/* Update toggle state of apps button */
+	/* Toggle application button in quicklaunch */
 	appsButton=xfdashboard_quicklaunch_get_apps_button(XFDASHBOARD_QUICKLAUNCH(priv->quicklaunch));
 	if(appsButton)
 	{
+		/* Block our signal handler at stage which is called when apps button's
+		 * state changes because it will enforce a specific view depending on its 
+		 * state which may not be the view which is going to be activated.
+		 */
+		g_signal_handlers_block_by_func(appsButton, _xfdashboard_stage_on_quicklaunch_apps_button_toggled, self);
+
+		/* Update toggle state of apps button */
 		if(G_OBJECT_TYPE(inView)==XFDASHBOARD_TYPE_SEARCH_VIEW ||
 			G_OBJECT_TYPE(inView)==XFDASHBOARD_TYPE_APPLICATIONS_VIEW)
 		{
@@ -534,6 +541,9 @@ static void _xfdashboard_stage_on_view_activated(XfdashboardStage *self, Xfdashb
 			{
 				xfdashboard_toggle_button_set_toggle_state(appsButton, FALSE);
 			}
+
+		/* Unblock any handler we blocked before */
+		g_signal_handlers_unblock_by_func(appsButton, _xfdashboard_stage_on_quicklaunch_apps_button_toggled, self);
 	}
 }
 
@@ -663,7 +673,7 @@ static void _xfdashboard_stage_on_application_resume(XfdashboardStage *self, gpo
 			/* First lookup view we should switch to by its internal name */
 			if(priv->switchToView)
 			{
-				resumeView=xfdashboard_viewpad_find_view_by_name(XFDASHBOARD_VIEWPAD(priv->viewpad), priv->switchToView);
+				resumeView=xfdashboard_viewpad_find_view_by_id(XFDASHBOARD_VIEWPAD(priv->viewpad), priv->switchToView);
 				if(!resumeView) g_warning(_("Will not switch to unknown view '%s'"), priv->switchToView);
 
 				/* Regardless if we could find view by its internal name or not
@@ -681,7 +691,7 @@ static void _xfdashboard_stage_on_application_resume(XfdashboardStage *self, gpo
 			 */
 			if(!resumeView)
 			{
-				resumeView=xfdashboard_viewpad_find_view_by_name(XFDASHBOARD_VIEWPAD(priv->viewpad), resumeViewInternalName);
+				resumeView=xfdashboard_viewpad_find_view_by_id(XFDASHBOARD_VIEWPAD(priv->viewpad), resumeViewInternalName);
 				if(!resumeView) g_warning(_("Cannot switch to unknown view '%s'"), resumeViewInternalName);
 			}
 
@@ -1315,7 +1325,7 @@ static void _xfdashboard_stage_show(ClutterActor *inActor)
 	if(priv->switchToView)
 	{
 		/* Look up view and switch to it if found */
-		switchView=xfdashboard_viewpad_find_view_by_name(XFDASHBOARD_VIEWPAD(priv->viewpad), priv->switchToView);
+		switchView=xfdashboard_viewpad_find_view_by_id(XFDASHBOARD_VIEWPAD(priv->viewpad), priv->switchToView);
 		if(switchView)
 		{
 			xfdashboard_viewpad_set_active_view(XFDASHBOARD_VIEWPAD(priv->viewpad), switchView);
