@@ -80,7 +80,7 @@ void xfdashboard_viewpad_set_spacing(XfdashboardViewpad *self, gfloat inSpacing)
 GList* xfdashboard_viewpad_get_views(XfdashboardViewpad *self);
 gboolean xfdashboard_viewpad_has_view(XfdashboardViewpad *self, XfdashboardView *inView);
 XfdashboardView* xfdashboard_viewpad_find_view_by_type(XfdashboardViewpad *self, GType inType);
-XfdashboardView* xfdashboard_viewpad_find_view_by_name(XfdashboardViewpad *self, const gchar *inInternalName);
+XfdashboardView* xfdashboard_viewpad_find_view_by_id(XfdashboardViewpad *self, const gchar *inID);
 
 XfdashboardView* xfdashboard_viewpad_get_active_view(XfdashboardViewpad *self);
 void xfdashboard_viewpad_set_active_view(XfdashboardViewpad *self, XfdashboardView *inView);
