@@ -128,7 +128,7 @@ static void _xfdashboard_windows_view_set_active_workspace(XfdashboardWindowsVie
 /* IMPLEMENTATION: Private variables and methods */
 #define SCROLL_EVENT_CHANGES_WORKSPACE_XFCONF_PROP		"/components/windows-view/scroll-event-changes-workspace"
 
-#define DEFAULT_VIEW_ICON								"gtk-fullscreen"
+#define DEFAULT_VIEW_ICON								"view-fullscreen"
 #define DEFAULT_DRAG_HANDLE_SIZE						32.0f
 
 /* Stage interface has changed monitor */
@@ -1938,7 +1938,6 @@ static void xfdashboard_windows_view_init(XfdashboardWindowsView *self)
 	priv->currentStageMonitorBindingID=0;
 
 	/* Set up view */
-	xfdashboard_view_set_internal_name(XFDASHBOARD_VIEW(self), "windows");
 	xfdashboard_view_set_name(XFDASHBOARD_VIEW(self), _("Windows"));
 	xfdashboard_view_set_icon(XFDASHBOARD_VIEW(self), DEFAULT_VIEW_ICON);
 	xfdashboard_view_set_view_fit_mode(XFDASHBOARD_VIEW(self), XFDASHBOARD_VIEW_FIT_MODE_BOTH);
@@ -1997,7 +1996,7 @@ static void xfdashboard_windows_view_init(XfdashboardWindowsView *self)
 	}
 }
 
-/* Implementation: Public API */
+/* IMPLEMENTATION: Public API */
 
 /* Get/set spacing between elements */
 gfloat xfdashboard_windows_view_get_spacing(XfdashboardWindowsView *self)
